@@ -22,6 +22,15 @@ test_that("Logistic GLMM with simple factor works", {
     lambda = irt.lam
   )
 
+  Xp <- predict(mod, newdata = dat[1:4, ], type = "lpmatrix")
+  expect_equal(dim(Xp), c(4L, 5L))
+
+  Xp <- predict(mod, newdata = dat[1, , drop = FALSE], type = "lpmatrix")
+  expect_equal(dim(Xp), c(1L, 5L))
+
+  Xp <- predict(mod, type = "lpmatrix")
+  expect_equal(dim(Xp), c(245L, 5L))
+
   expect_snapshot(summary(mod))
 
   expect_equal(
@@ -53,11 +62,21 @@ test_that("Logistic GLMM with simple factor works", {
     c(-1.78690466704062, -0.703586683984688, -0.89579766346322)
   )
 
+  expect_equal(
+    residuals(mod, type = "deviance", scaled = TRUE)[[7]],
+    -1.26299208558568
+  )
+
   expect_equal(
     residuals(mod, type = "pearson")[c(2, 3, 9)],
     c(0.34711634976693, 0.810706452322364, -0.987045133505393)
   )
 
+  expect_equal(
+    residuals(mod, type = "pearson", scaled = TRUE)[[7]],
+    -1.23177063323396
+  )
+
   set.seed(1234)
   dat <- IRTsim
   dat$trials <- sample(1:10, nrow(dat), replace = TRUE)
@@ -155,3 +174,31 @@ test_that(
     expect_equal(factor_loadings(mod), factor_loadings(mod0))
   }
 )
+
+test_that("diagnostic plots work", {
+  data("cbpp", package = "lme4")
+  mod <- galamm(cbind(incidence, size - incidence) ~ period + (1 | herd),
+                data = cbpp, family = binomial)
+
+  expect_s3_class(plot(mod, resid(., type = "deviance") ~ fitted(.) | herd),
+                  "trellis")
+
+  expect_s3_class(
+    plot(mod, resid(., type = "deviance") ~ fitted(.) | herd, abline = c(0, 1)),
+    "trellis")
+
+  data("sleepstudy", package = "lme4")
+  mod <- galamm(Reaction ~ Days + (Days | Subject), data = sleepstudy)
+
+  expect_s3_class(
+    plot(mod, form = resid(., type = "pearson") ~ Days | Subject,
+         abline = c(0, 0)),
+    "trellis"
+  )
+
+  expect_s3_class(
+    plot(mod, form = Subject ~ resid(., type = "deviance", scaled = TRUE)),
+    "trellis"
+  )
+
+})
